@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::CLI::Testrun::Command::deletehost::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::CLI::Testrun::Command::deletehost::VERSION = '4.0.1';
+  $Tapper::CLI::Testrun::Command::deletehost::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -74,7 +74,7 @@ sub execute {
 
  NAME:
         foreach my $name (@{$opt->{name}}) {
-                my $host = model('TestrunDB')->resultset('Host')->search({name => $name})->first;
+                my $host = model('TestrunDB')->resultset('Host')->search({name => $name}, {rows => 1})->first;
                 push @{$opt->{id}}, $host->id;
         }
 
