@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::CLI::Testrun::Command::deletequeue::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::CLI::Testrun::Command::deletequeue::VERSION = '4.0.1';
+  $Tapper::CLI::Testrun::Command::deletequeue::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -85,7 +85,7 @@ sub delete_queue
 {
         my ($self, $opt, $args) = @_;
 
-        my $queue = model('TestrunDB')->resultset('Queue')->search({name => $opt->{name}})->first;
+        my $queue = model('TestrunDB')->resultset('Queue')->search({name => $opt->{name}}, {rows => 1})->first;
         die "No such queue: ".$opt->{name} if not $queue;
 
         my $cmd = Tapper::Cmd::Queue->new();
