@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::CLI::Testrun::Command::listhost::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::CLI::Testrun::Command::listhost::VERSION = '4.0.1';
+  $Tapper::CLI::Testrun::Command::listhost::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -119,41 +119,57 @@ sub execute {
         }
 }
 
+sub host_feature_summary
+{
+        my ($host) = @_;
+
+        return join(",",
+                    map { $_->value }
+                    sort { $a->entry cmp $b->entry }
+                    grep { $_->entry =~ /^(key_word|socket_type|revision)$/ }
+                    $host->features->all
+                   );
+}
 
 sub print_hosts_verbose
 {
         my ($self, $hosts) = @_;
         my %max = (
                    name    => 4,
+                   features => 10,
                    comment => 7,
                    queue   => 0,
                   );
  HOST:
         foreach my $host ($hosts->all) {
+                my $features = host_feature_summary($host);
                 $max{name}    = length($host->name) if length($host->name) > $max{name};
+                $max{features} = length($features) if length($features) > $max{features};
                 $max{comment} = length($host->comment) if length($host->comment) > $max{comment};
                 next HOST if not $host->queuehosts->count;
                 foreach my $queuehost ($host->queuehosts->all) {
                         $max{queue} = length($queuehost->queue->name) if length($queuehost->queue->name) > $max{queue};
                 }
         }
-        my ($name_length, $comment_length, $queue_length) = ($max{name}, $max{comment}, $max{queue});
+        my ($name_length, $feature_length, $comment_length, $queue_length) = ($max{name}, $max{features}, $max{comment}, $max{queue});
 
         # use printf to get the wanted field width
-        printf ("%5s | %${name_length}s | %11s | %10s | %${comment_length}s | Queues\n",'ID','Name','Active', 'Testrun ID', 'Comment');
-        say "="x(5+$name_length+11+length('Testrun ID')+$comment_length+length('Queues')+5*length(' | '));
+        printf ("%5s | %${name_length}s | %-${feature_length}s | %11s | %10s | %${comment_length}s | Queues\n", 'ID', 'Name', 'Features', 'Active', 'Testrun ID', 'Comment');
+        say "="x(5+$name_length+$feature_length+11+length('Testrun ID')+$comment_length+length('Queues')+6*length(' | '));
 
 
         foreach my $host ($hosts->all) {
-                my ($name_length, $queue_length) = ($max{name}, $max{queue});
+                my ($name_length, $feature_length, $queue_length) = ($max{name}, $max{features}, $max{queue});
                 my $testrun_id = 'unknown id';
                 if (not $host->free) {
                         my $job_rs = model('TestrunDB')->resultset('TestrunScheduling')->search({host_id => $host->id, status => 'running'});
-                        $testrun_id = $job_rs->first->testrun_id if $job_rs->count;
+                        $testrun_id = $job_rs->search({}, {rows => 1})->first->testrun_id if $job_rs->count;
                 }
-                my $output = sprintf("%5d | %${name_length}s | %11s | %10s | %${comment_length}s | ",
+                my $features = host_feature_summary($host);
+                my $output = sprintf("%5d | %${name_length}s | %-${feature_length}s | %11s | %10s | %${comment_length}s | ",
                                      $host->id,
                                      $host->name,
+                                     $features,
                                      $host->is_deleted ? 'deleted' : ( $host->active ? 'active' : 'deactivated' ),
                                      $host->free   ? 'free'   : "$testrun_id",
                                      $host->comment,
