@@ -3,7 +3,7 @@ BEGIN {
   $Tapper::CLI::Testrun::Command::listqueue::AUTHORITY = 'cpan:AMD';
 }
 {
-  $Tapper::CLI::Testrun::Command::listqueue::VERSION = '4.0.1';
+  $Tapper::CLI::Testrun::Command::listqueue::VERSION = '4.1.0';
 }
 
 use 5.010;
@@ -136,6 +136,12 @@ sub print_queues_verbose
                         $output  .= join ", ",@hosts;
                         $output  .= "\n";
                 }
+                if ($queue->deniedhosts->count) {
+                        my @hosts = map {$_->host->name} $queue->deniedhosts->all;
+                        $output  .= "Denied hosts: ";
+                        $output  .= join ", ",@hosts;
+                        $output  .= "\n";
+                }
                 if ($queue->queued_testruns->count) {
                         my @ids   = map {$_->testrun_id} $queue->queued_testruns->all;
                         $output  .= "Queued testruns (ids): ";
